@@ -8,6 +8,6 @@ use Test::Kit
   'TestIsDeeply',
   '+on_fail',
   '+explain',
-  'Test::More' => { exclude => 'is_deeply' };
+  'Test::More' => { exclude => [qw/is_deeply explain/] };
 
 1;
